==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeOrFilteringOperationDescription } from "./WebFilteringExpressionsTreeOrFilteringOperationDescription";
/**
 * @hidden
 */
export let WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a == null) {
                WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.c(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a);
            }
            if (a.k(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringExpressionsTreeOrFilteringOperation");
        }
        static d(a) {
            WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.b(a);
            a.ad("WebFilteringExpressionsTreeOrFilteringOperation", () => new WebFilteringExpressionsTreeOrFilteringOperationDescription());
            a.ac("WebFilteringExpressionsTreeOrFilteringOperation", WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a);
        }
    }
    WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.$t = markType(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata, 'WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata');
    WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a = null;
    return WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeOrFilteringOperationDescription } from "./WebFilteringExpressionsTreeOrFilteringOperationDescription";
/**
 * @hidden
 */
export let WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a == null) {
                WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.c(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a);
            }
            if (a.k(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringExpressionsTreeOrFilteringOperation");
        }
        static d(a) {
            WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.b(a);
            a.ae("WebFilteringExpressionsTreeOrFilteringOperation", () => new WebFilteringExpressionsTreeOrFilteringOperationDescription());
            a.ad("WebFilteringExpressionsTreeOrFilteringOperation", WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a);
        }
    }
    WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.$t = markType(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata, 'WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata');
    WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a = null;
    return WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata;
})();
